---
sidebar_position: 80
title: 设备管理
---

## 获取设备列表

### 导入 device 模块

```js
import { device } from '@rongcloud/plugin-rtc'
```

### 获取麦克风设备列表

API 参考：[getMicrophones](https://doc.rongcloud.cn/apidoc/rtc-web/latest/modules.html#device)

```js
const microphones = await device.getMicrophones();
```

### 获取摄像头设备列表

API 参考：[getCameras](https://doc.rongcloud.cn/apidoc/rtc-web/latest/modules.html#device)

```js
const cameras = await device.getCameras();
```

### 获取扬声器设备列表

API 参考：[getSpeakers](https://doc.rongcloud.cn/apidoc/rtc-web/latest/modules.html#device)

```js
const speakers = await device.getSpeakers()
```

## 从指定设备获取音视频资源

如果已获取设备的 ID，例如 `micphoneId`、`cameraId` 等，可以使用以下方法从指定设备获取音视频资源。

### 从指定设备获取音频

获取音频 track 时可指定设备 ID。

API 参考：[createMicrophoneAudioTrack](https://doc.rongcloud.cn/apidoc/rtc-web/latest/classes/RCRTCClient.html#createMicrophoneAudioTrack)

```typescript
/**
 * @param tag 资源标识
 * @param IMicphoneAudioProfile.micphoneId 指定麦克风设备 Id
*/
const { code, track: audioTrack } = await rtcClient.createMicrophoneAudioTrack(tag: string = 'RongCloudRTC', options?: IMicphoneAudioProfile)
```

### 从指定设备获取视频

获取视频 track 时可指定设备 ID。

API 参考：[createCameraVideoTrack](https://doc.rongcloud.cn/apidoc/rtc-web/latest/classes/RCRTCClient.html#createCameraVideoTrack)

```typescript
/**
 * @param tag 资源标识
 * @param ICameraVideoProfile.cameraId 指定摄像头设备 Id
*/
const { code, track: videoTrack } = await rtcClient.createCameraVideoTrack(tag: string = 'RongCloudRTC', options?: ICameraVideoProfile)
```

### 从指定设备同时获取音视频

同时获取音频 track 和视频 track 时可指定设备 ID。

API 参考：[createMicrophoneAndCameraTracks](https://doc.rongcloud.cn/apidoc/rtc-web/latest/classes/RCRTCClient.html#createMicrophoneAndCameraTracks)

```typescript
/**
 * @param tag 资源标识
 * @param IMicphoneAudioProfile.micphoneId 指定麦克风设备 Id
 * @param ICameraVideoProfile.cameraId 指定摄像头设备 Id
*/
const { code, tracks } = await rtcClient.createMicrophoneAndCameraTracks(tag: string = 'RongCloudRTC', options?: { audio?: IMicphoneAudioProfile, video?: ICameraVideoProfile })
```
